# Создание псевдонимов (alias) для часто используемых команд

## Содержание

-   [Общее](#общее)
-   [Подключение к сессии Tmux при подключении по SSH](#подключение-к-сессии-tmux-при-подключении-по-ssh)

## Общее

Все алиасы прописываются для конкретного пользователя в файле `~/.bashrc`
_например, чтобы вывести данные по IP в цвете необходимо ввести `ip --color=auto a`_
можно создать такой алиас: `alias ip='ip --color=auto'`

**Перелогиниться** и теперь при вводе `ip a` вывод будет цветной

Таким образом можно делать псевдонимы для любых команд:

```bash
alias ll='ls -l'
alias upd='apt update && apt upgrade -y && apt autoremove -y'
```

Кроме алиасов в .bashrc можно добавлять целые функции:

```bash
wanip() {
wget -q -O - checkip.dyndns.com | awk '{print $6}'| sed 's/<.*>//'
}
```

_перелогиниться_. Функция отображает внешний IP

```bash
pi@testberry:~ $ wanip
85.143.252.68
```

**_А лучше вынести в отдельный файл, для этого в `.bashrc` добавить_**

```bash
if [ -f ~/.bash_func ]; then
. ~/.bash_func
fi
```

`.bash_func` — имя файла, где и будем писать функции.

[⬆ Наверх](#содержание)

## Подключение к сессии Tmux при подключении по SSH

В конец файла `.bashrc` добавить:

```bash
# start tmux session for all ssh connections
if [[ -n "$PS1" ]] && [[ -z "$TMUX" ]] && [[ -n "$SSH_CONNECTION" ]]; then
  tmux attach-session -t ssh_tmux || tmux new-session -s ssh_tmux
fi
```

[⬆ Наверх](#содержание)
